@@ -1,5 +1,5 @@
-from cluster import LPCGatewayCluster 
-from gateway import LPCGateway 
+from .cluster import LPCGatewayCluster 
+from .gateway import LPCGateway 
 
 # @author Maria A. - mapsacosta
 
